@@ -163,7 +163,6 @@ class Tasks:
                 'relative_uri': '',
                 'headers': {
                     'Content-type': 'application/json',
-                    'Authorization': 'Token {}'.format('')
                 },
             }
         }
@@ -181,6 +180,10 @@ class Tasks:
 
         for payload in self.payloads:
 
+            # Clean comment
+            if payload.get('comment'):
+                payload.get['comment'] = str(payload.get('comment'))[:255]
+
             # Convert dict to JSON string
             payload_string = json.dumps(payload)
 
@@ -194,4 +197,4 @@ class Tasks:
 
             self.client.create_task(parent=self.parent, task=task)
 
-            return Status.SUCCESS, 200
+        return Status.SUCCESS, 200
